Struct amazon_sp_aplus_content::models::standard_image_text_caption_block::StandardImageTextCaptionBlock
source · [−]pub struct StandardImageTextCaptionBlock {
pub block: Option<Box<StandardImageTextBlock>>,
pub caption: Option<Box<TextComponent>>,
}Expand description
StandardImageTextCaptionBlock : The A+ Content standard image and text block, with a related caption. The caption may not display on all devices.
Fields
block: Option<Box<StandardImageTextBlock>>caption: Option<Box<TextComponent>>Implementations
sourceimpl StandardImageTextCaptionBlock
impl StandardImageTextCaptionBlock
sourcepub fn new() -> StandardImageTextCaptionBlock
pub fn new() -> StandardImageTextCaptionBlock
The A+ Content standard image and text block, with a related caption. The caption may not display on all devices.